#!/usr/bin/env python3
# Adapted from https://stackoverflow.com/questions/24236266/how-to-extract-dependencies-information-from-a-setup-py
# https://stackoverflow.com/users/748858/mgilson
#
# Gen-requirements extracts requirements from the setup.py to generate a requirements.txt.
# This allows for a single source of dependencies (truth) in our setup.py file.
# Only used for CI purposes.

from unittest import mock
import setuptools

with mock.patch.object(setuptools, "setup") as mock_setup:
    import setup  # This is setup.py which calls setuptools.setup

_, kwargs = mock_setup.call_args

install_requires = kwargs.get("install_requires", [])
extras_require = kwargs.get("extras_require", [])["dev"]

with open("requirements.txt", "w") as f:
    f.write(
        f"# Auto generated by {__file__} from setup.py.\n# Change requirements in setup.py.\n"
    )
    f.write("\n".join(install_requires + extras_require))
